quantizationtools.QEventSequence
================================

.. abjad-lineage:: abjad.tools.quantizationtools.QEventSequence.QEventSequence

.. autoclass:: abjad.tools.quantizationtools.QEventSequence.QEventSequence

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.duration_in_ms
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.from_millisecond_durations
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.from_millisecond_offsets
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.from_millisecond_pitch_pairs
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.from_tempo_scaled_durations
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.from_tempo_scaled_leaves
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.sequence
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.__contains__
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.__eq__
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.__format__
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.__getitem__
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.__iter__
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.__len__
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.__ne__
      ~abjad.tools.quantizationtools.QEventSequence.QEventSequence.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.duration_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.sequence
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.from_millisecond_durations
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.from_millisecond_offsets
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.from_millisecond_pitch_pairs
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.from_tempo_scaled_durations
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.from_tempo_scaled_leaves
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.__contains__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.__getitem__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.__iter__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.__len__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QEventSequence.QEventSequence.__repr__
   :noindex:
